<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class HorizontalMenu extends componentEntity
{
    public function __construct(array $menu = null)
    {
        parent::__construct();
        $this->setColWidth('xs', 12);
        $this->setID('TopBarMainMenu');
        if ($menu) {
            $this->addProperty('menuItems', $menu);
        }
    }
}
