<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class RowWrapper extends componentEntity
{
    public function __construct()
    {
        parent::__construct();
        $this->addClass('m-0');
    }
}
